@@ -39,7 +39,7 @@ violin.plot <- function(data){
   # Reshape the dataframe to make it appropriate to ggplot2 syntax
   p <- tibble::as_tibble(data) %>%
     reshape2::melt(id = "label") %>%
-    left_join(as.data.frame(waves)) %>%
+    left_join(as.data.frame(waves), by = "variable") %>%
     mutate(across("label", as.factor)) %>%
     mutate(across("dummy_wavelength", as.numeric)) %>%
     mutate(across("variable", as.factor)) %>%
@@ -47,7 +47,7 @@ violin.plot <- function(data){
     mutate(variable = factor(.data$variable,
                              levels = c("B2","B3","B4","B5","B6","B7","B8","B8A","B11","B12"))) %>%
     na.omit() %>%
-    ggplot(aes_string(x = "label", y = "value", fill = "label"))+
+    ggplot(aes(x = .data$label, y = .data$value, fill = .data$label))+
     geom_violin(trim = FALSE)+
     facet_wrap( ~ variable,
                 ncol = 2,
